==> vue-components-1.5.42.tgz: package/lib/select/SelectDropdown.vue.rd.js <==
import { useInjectStyle as U } from "../shared/hooks/useInjectStyle.rd.js";
import { useVModel as q } from "@vueuse/core";
import { defineComponent as G, toRefs as H, computed as y, openBlock as s, createElementBlock as i, createVNode as D, unref as e, mergeProps as P, withCtx as g, createElementVNode as a, withDirectives as J, isRef as O, withModifiers as Q, vModelText as W, createCommentVNode as p, Fragment as k, renderList as X, createBlock as R, normalizeClass as $, resolveDynamicComponent as Y, toDisplayString as Z, renderSlot as V, normalizeProps as ee } from "vue";
import "../node_modules/ant-design-vue/es/dropdown/index.rd.js";
import { usePopupContainer as te } from "@regiondev/vue-hooks";
import { useFocus as oe } from "../shared/hooks/useFocus.rd.js";
import { selectDropdownProps as re } from "./selectProps.rd.js";
/* empty css                                                       *//* empty css                                                              *//* empty css                                                            */import se from "../node_modules/ant-design-vue/es/dropdown/style/index.css.rd.js";
import "../spinners/index.rd.js";
import "../dropdown/index.rd.js";
import le from "../spinners/src/Spinner.vue.rd.js";
import ne from "../dropdown/src/DropdownItem.vue.rd.js";
import ie from "../node_modules/ant-design-vue/es/dropdown/dropdown.rd.js";
const ae = { class: "dropdown-slot-container" }, ce = { class: "bg-white dark:!bg-rdSurface-800 app-dropdown round py-1.5 shadow-md" }, de = {
  key: 0,
  class: "py-1 px-2"
}, ue = ["placeholder"], pe = {
  key: 1,
  class: "px-3 w-full mx-auto justify-center py-3 flex"
}, fe = {
  key: 2,
  class: "max-h-300px overflow-auto"
}, me = {
  key: 0,
  class: "ml-1"
}, he = { class: "w-full flex color-inherit whitespace-nowrap flex-row space-x-3" }, ye = { class: "whitespace-nowrap color-inherit" }, ve = /* @__PURE__ */ a("span", { class: "text-md font-normal !ml-auto text-17px i-heroicons-outline:check" }, null, -1), _e = [
  ve
], ge = {
  key: 3,
  class: "!opacity-90 text-center justify-center flex flex-col items-center py-3"
}, ke = /* @__PURE__ */ a("span", { class: "text-4xl text-muted i-ic:baseline-search-off" }, null, -1), we = /* @__PURE__ */ a("span", { class: "text-muted" }, "No results", -1), xe = [
  ke,
  we
], Le = /* @__PURE__ */ G({
  __name: "SelectDropdown",
  props: re(),
  emits: ["clickedItem", "filter"],
  setup(A, { expose: F, emit: N }) {
    const w = A;
    U(se, "ant-dropdown");
    const f = q(w, "filter"), { items: n, loading: x, textKey: b, idKey: u, selected: r, multiple: C, trigger: j, getPopupContainer: v } = H(w), { container: z, getContainer: B } = te(v == null ? void 0 : v.value), _ = y(() => Array.isArray(r == null ? void 0 : r.value) ? null : r == null ? void 0 : r.value), m = y(() => Array.isArray(r == null ? void 0 : r.value) ? r == null ? void 0 : r.value : null);
    function E(t, l) {
      N("clickedItem", { item: t, key: t[u.value], event: l });
    }
    const S = y(() => {
      var t;
      return (t = n == null ? void 0 : n.value) == null ? void 0 : t.filter(
        (l) => {
          var c, d;
          return (d = l[b.value]) == null ? void 0 : d.toLowerCase().includes((c = f.value) == null ? void 0 : c.toLowerCase());
        }
      );
    }), L = y(() => {
      var t, l, c, d;
      return !x.value && (((t = n == null ? void 0 : n.value) == null ? void 0 : t.length) != 0 && ((l = n == null ? void 0 : n.value) == null ? void 0 : l.length) == ((c = m.value) == null ? void 0 : c.length) || ((d = S.value) == null ? void 0 : d.length) == 0);
    }), { ref: M, focus: K } = oe();
    return F({
      focusFilter: K
    }), (t, l) => (s(), i("div", {
      ref_key: "container",
      ref: z,
      class: "flex"
    }, [
      D(e(ie), P({
        getPopupContainer: e(B),
        disabled: t.disabled
      }, t.$attrs, { trigger: e(j) }), {
        overlay: g(() => {
          var c, d;
          return [
            a("div", ce, [
              t.showFilter ? (s(), i("div", de, [
                J(a("input", {
                  ref_key: "filterRef",
                  ref: M,
                  "onUpdate:modelValue": l[0] || (l[0] = (o) => O(f) ? f.value = o : null),
                  class: "border round border-solid text-theme border-theme outline-none px-2 py-1 w-full rounded-md dark:bg-rdSurface-800 dark:hover:bg-rdSurface-700 dark:active:bg-rdSurface-800 dark:focus:bg-rdSurface-800",
                  type: "text",
                  placeholder: t.filterPlaceholder,
                  onClick: l[1] || (l[1] = Q(() => ({}), ["prevent", "stop"]))
                }, null, 8, ue), [
                  [W, e(f)]
                ])
              ])) : p("", !0),
              e(x) ? (s(), i("div", pe, [
                D(e(le), {
                  loading: !0,
                  size: "22",
                  inherit: !0,
                  class: "text-gray-400"
                })
              ])) : !e(C) || ((c = e(n)) == null ? void 0 : c.length) !== ((d = e(m)) == null ? void 0 : d.length) ? (s(), i("div", fe, [
                (s(!0), i(k, null, X(e(S), (o, T) => {
                  var I;
                  return s(), i(k, { key: T }, [
                    !e(C) || !t.hideSelected || !((I = e(m)) != null && I.includes(o[e(u)])) ? (s(), R(e(ne), {
                      key: 0,
                      class: "group/dropdownitem",
                      active: e(_) ? o[e(u)] == e(_) : !1,
                      onClick: (h) => E(o, h)
                    }, {
                      default: g(() => {
                        var h;
                        return [
                          t.$slots.itemRender ? V(t.$slots, "itemRender", ee(P({ key: 1 }, { item: o }))) : (s(), i(k, { key: 0 }, [
                            o.icon ? (s(), i("div", me, [
                              typeof o.icon == "string" ? (s(), i("span", {
                                key: 0,
                                class: $(o.icon)
                              }, null, 2)) : (s(), R(Y(o.icon), { key: 1 }))
                            ])) : p("", !0),
                            a("span", he, [
                              a("span", ye, Z(o[e(b)]), 1),
                              a("span", {
                                class: $([{ "!opacity-100": ((h = e(m)) == null ? void 0 : h.includes(o[e(u)])) || e(_) == o[e(u)] }, "group-hover/dropdownitem:text-white opacity-0 text-primary-600 !ml-auto pl-5 dark:text-primary-400 dark:group-hover:text-primary-400 group-hover/item:text-white"])
                              }, _e, 2)
                            ])
                          ], 64))
                        ];
                      }),
                      _: 2
                    }, 1032, ["active", "onClick"])) : p("", !0)
                  ], 64);
                }), 128))
              ])) : p("", !0),
              e(L) ? (s(), i("div", ge, xe)) : p("", !0)
            ])
          ];
        }),
        default: g(() => [
          a("div", ae, [
            V(t.$slots, "default")
          ])
        ]),
        _: 3
      }, 16, ["getPopupContainer", "disabled", "trigger"])
    ], 512));
  }
});
export {
  Le as default
};

==> vue-components-1.5.43.tgz: package/lib/select/SelectDropdown.vue.rd.js <==
import { useInjectStyle as U } from "../shared/hooks/useInjectStyle.rd.js";
import { useVModel as q } from "@vueuse/core";
import { defineComponent as G, toRefs as H, computed as y, openBlock as s, createElementBlock as i, createVNode as D, unref as e, mergeProps as P, withCtx as g, createElementVNode as a, withDirectives as J, isRef as O, withModifiers as Q, vModelText as W, createCommentVNode as p, Fragment as k, renderList as X, createBlock as R, normalizeClass as $, resolveDynamicComponent as Y, toDisplayString as Z, renderSlot as V, normalizeProps as ee } from "vue";
import "../node_modules/ant-design-vue/es/dropdown/index.rd.js";
import { usePopupContainer as te } from "@regiondev/vue-hooks";
import { useFocus as oe } from "../shared/hooks/useFocus.rd.js";
import { selectDropdownProps as re } from "./selectProps.rd.js";
/* empty css                                                       *//* empty css                                                              *//* empty css                                                            */import se from "../node_modules/ant-design-vue/es/dropdown/style/index.css.rd.js";
import "../spinners/index.rd.js";
import "../dropdown/index.rd.js";
import le from "../spinners/src/Spinner.vue.rd.js";
import ne from "../dropdown/src/DropdownItem.vue.rd.js";
import ie from "../node_modules/ant-design-vue/es/dropdown/dropdown.rd.js";
const ae = { class: "dropdown-slot-container" }, de = { class: "bg-white dark:!bg-rdSurface-800 border-solid border-theme border-1 app-dropdown round py-1.5 shadow-md" }, ce = {
  key: 0,
  class: "py-1 px-2"
}, ue = ["placeholder"], pe = {
  key: 1,
  class: "px-3 w-full mx-auto justify-center py-3 flex"
}, fe = {
  key: 2,
  class: "max-h-300px overflow-auto"
}, me = {
  key: 0,
  class: "ml-1 flex mr-2"
}, he = { class: "w-full flex !color-inherit whitespace-nowrap flex-row space-x-3" }, ye = { class: "whitespace-nowrap !color-inherit" }, ve = /* @__PURE__ */ a("span", { class: "text-md font-normal !ml-auto text-17px i-heroicons-outline:check" }, null, -1), _e = [
  ve
], ge = {
  key: 3,
  class: "!opacity-90 text-center justify-center flex flex-col items-center py-3"
}, ke = /* @__PURE__ */ a("span", { class: "text-4xl text-muted i-ic:baseline-search-off" }, null, -1), we = /* @__PURE__ */ a("span", { class: "text-muted" }, "No results", -1), xe = [
  ke,
  we
], Le = /* @__PURE__ */ G({
  __name: "SelectDropdown",
  props: re(),
  emits: ["clickedItem", "filter"],
  setup(A, { expose: F, emit: N }) {
    const w = A;
    U(se, "ant-dropdown");
    const f = q(w, "filter"), { items: n, loading: x, textKey: b, idKey: u, selected: r, multiple: C, trigger: j, getPopupContainer: v } = H(w), { container: z, getContainer: B } = te(v == null ? void 0 : v.value), _ = y(() => Array.isArray(r == null ? void 0 : r.value) ? null : r == null ? void 0 : r.value), m = y(() => Array.isArray(r == null ? void 0 : r.value) ? r == null ? void 0 : r.value : null);
    function E(t, l) {
      N("clickedItem", { item: t, key: t[u.value], event: l });
    }
    const S = y(() => {
      var t;
      return (t = n == null ? void 0 : n.value) == null ? void 0 : t.filter(
        (l) => {
          var d, c;
          return (c = l[b.value]) == null ? void 0 : c.toLowerCase().includes((d = f.value) == null ? void 0 : d.toLowerCase());
        }
      );
    }), L = y(() => {
      var t, l, d, c;
      return !x.value && (((t = n == null ? void 0 : n.value) == null ? void 0 : t.length) != 0 && ((l = n == null ? void 0 : n.value) == null ? void 0 : l.length) == ((d = m.value) == null ? void 0 : d.length) || ((c = S.value) == null ? void 0 : c.length) == 0);
    }), { ref: M, focus: K } = oe();
    return F({
      focusFilter: K
    }), (t, l) => (s(), i("div", {
      ref_key: "container",
      ref: z,
      class: "flex"
    }, [
      D(e(ie), P({
        getPopupContainer: e(B),
        disabled: t.disabled
      }, t.$attrs, { trigger: e(j) }), {
        overlay: g(() => {
          var d, c;
          return [
            a("div", de, [
              t.showFilter ? (s(), i("div", ce, [
                J(a("input", {
                  ref_key: "filterRef",
                  ref: M,
                  "onUpdate:modelValue": l[0] || (l[0] = (o) => O(f) ? f.value = o : null),
                  class: "border round border-solid text-theme border-theme outline-none px-2 py-1 w-full rounded-md dark:bg-rdSurface-800 dark:hover:bg-rdSurface-700 dark:active:bg-rdSurface-800 dark:focus:bg-rdSurface-800",
                  type: "text",
                  placeholder: t.filterPlaceholder,
                  onClick: l[1] || (l[1] = Q(() => ({}), ["prevent", "stop"]))
                }, null, 8, ue), [
                  [W, e(f)]
                ])
              ])) : p("", !0),
              e(x) ? (s(), i("div", pe, [
                D(e(le), {
                  loading: !0,
                  size: "22",
                  inherit: !0,
                  class: "text-gray-400"
                })
              ])) : !e(C) || ((d = e(n)) == null ? void 0 : d.length) !== ((c = e(m)) == null ? void 0 : c.length) ? (s(), i("div", fe, [
                (s(!0), i(k, null, X(e(S), (o, T) => {
                  var I;
                  return s(), i(k, { key: T }, [
                    !e(C) || !t.hideSelected || !((I = e(m)) != null && I.includes(o[e(u)])) ? (s(), R(e(ne), {
                      key: 0,
                      class: "group/dropdownitem",
                      active: e(_) ? o[e(u)] == e(_) : !1,
                      onClick: (h) => E(o, h)
                    }, {
                      default: g(() => {
                        var h;
                        return [
                          t.$slots.itemRender ? V(t.$slots, "itemRender", ee(P({ key: 1 }, { item: o }))) : (s(), i(k, { key: 0 }, [
                            o.icon ? (s(), i("div", me, [
                              typeof o.icon == "string" ? (s(), i("span", {
                                key: 0,
                                class: $(o.icon)
                              }, null, 2)) : (s(), R(Y(o.icon), { key: 1 }))
                            ])) : p("", !0),
                            a("span", he, [
                              a("span", ye, Z(o[e(b)]), 1),
                              a("span", {
                                class: $([{ "!opacity-100": ((h = e(m)) == null ? void 0 : h.includes(o[e(u)])) || e(_) == o[e(u)] }, "group-hover/dropdownitem:text-white opacity-0 text-primary-600 !ml-auto pl-5 dark:text-primary-400 dark:group-hover:text-primary-400 group-hover/item:text-white"])
                              }, _e, 2)
                            ])
                          ], 64))
                        ];
                      }),
                      _: 2
                    }, 1032, ["active", "onClick"])) : p("", !0)
                  ], 64);
                }), 128))
              ])) : p("", !0),
              e(L) ? (s(), i("div", ge, xe)) : p("", !0)
            ])
          ];
        }),
        default: g(() => [
          a("div", ae, [
            V(t.$slots, "default")
          ])
        ]),
        _: 3
      }, 16, ["getPopupContainer", "disabled", "trigger"])
    ], 512));
  }
});
export {
  Le as default
};
